@@ -1,8 +1,8 @@
 
-__version__ = "0.11.5"
+__version__ = "0.11.7"
 __version_vcs_info__ = {
-    'branch': 'hotfix-0.11.5',
-    'revid': '0d95224',
-    'revno': 1929}
+    'branch': 'master',
+    'revid': '0baa648',
+    'revno': 1933}
 __version_user_email__ = "saxtouri@admin.grnet.gr"
 __version_user_name__ = "Stavros Sachtouris"
